#!/bin/bash -e
configDir=/etc/azsec/baseimage
# Pull in shared functions
source /usr/local/bin/shared-baseimage.sh
# Determine which OS Version we're using
if [ -z "OSMAJORVER" ]; then
    echo "Failed to pull in shared functions from /usr/local/bin/shared-baseimage.sh"
    exit 1
fi
TryAptInstall unattended-upgrades azure-baseimage-patch
apt-get autoremove -y
updatedb
# Add DNS retries
echo "options timeout:1 attempts:5" >> /etc/resolvconf/resolv.conf.d/head
service resolvconf restart
# Disable lwresd, enable unscd
if [ -e /etc/nscd.conf ]; then
	apt-get remove -y libnss-lwres lwresd
	sed -i 's/lwres\s*//g' /etc/nsswitch.conf
	sed -i 's/\(^hosts:\s\+files\s\+\)/\1cache /g' /etc/nsswitch.conf
	sed -i 's/\(enable-cache\s\+hosts\s\+\)[a-z]\+/\1yes/g' /etc/nscd.conf
else
	echo "Could not find /etc/nscd.conf - skipping nscd config and leaving lwresd installed"
fi
# Update dhcp timeout
sed -i 's/long=[0-9]*/long=240/g' /etc/init/cloud-init-nonet.conf
# Create JAVA_HOME variable for all users
if [ -e /usr/lib/jvm/java-7-openjdk-amd64 ]; then
    JAVADIR=/usr/lib/jvm/java-7-openjdk-amd64
else
    JAVADIR=/usr/lib/jvm/java-8-openjdk-amd64
fi
echo export JAVA_HOME=$JAVADIR >> /etc/profile
echo export JAVA_HOME=$JAVADIR >> /etc/skel/.bashrc
echo export JAVA_HOME=$JAVADIR >> /root/.bashrc
# Allow sudo to pull in /etc/environment in 14.04, this is fixed in 16.04
if [ $OSMAJORVER -eq 14 ]; then
    echo "session    required   pam_env.so readenv=1" >> /etc/pam.d/sudo
fi

# Raise open file limit from 1024
echo "*  soft  nofile 10000" >> /etc/security/limits.conf
echo "*  hard  nofile 10000" >> /etc/security/limits.conf
echo "root  soft  nofile 10000" >> /etc/security/limits.conf
echo "root  hard  nofile 10000" >> /etc/security/limits.conf
echo "session required pam_limits.so" >> /etc/pam.d/common-session

# Apply baseline security configuration
/usr/local/bin/apply-secbaseline.sh

# Needs to be done after dist-upgrade in case a newly installed package regresses
if ! TryFixDhcpOptionIfNeeded; then
    dhcpOption=$(grep "send host-name" $dhclientConf)
    bail "DHCP option [$dhcpOption] is not valid for Ubuntu $OSVER"
fi

# If the kernel panics reboot the VM in 30 seconds.
# 50-cloudimg-settings.cfg is a pre-determined settings file that sets
# the kernel cmdline.  Pick 60 to ensure we execute after this
# setting.
echo "GRUB_CMDLINE_LINUX_DEFAULT=\"\$GRUB_CMDLINE_LINUX_DEFAULT panic=30\"" > /etc/default/grub.d/60-kernel-panic.cfg
update-grub

# Using 2.x azure-security package
AZSEC_CYCLE=P1D
declare -a scans=("baseline" "clamav" "software")

# Enable scanners
for scan in ${scans[@]};do
    azsecd config -d $AZSEC_CYCLE -s $scan
done

# Disable hv-fcopy-daemon.service since we don't use it
if [[ $OSMAJORVER -ge 16 ]]; then
    # Service does not exist in 14.04
    systemctl disable hv-fcopy-daemon.service
fi
